@@ -235,7 +235,7 @@ class VersionedFile(AnyEntity):
 
     def dc_long_title(self):
         try:
-            return self._cw._('%(path)s (from repository %(repotype)s:%(repo)s)') % {
+            return self._cw._('%(path)s (from %(repotype)s repository: %(repo)s)') % {
                 'path': self.dc_title(), 'repo': self.repository.dc_title(),
                 'repotype': self.repository.type}
         except Unauthorized:
