@@ -123,6 +123,13 @@ class VCSFileStartHook(hook.Hook):
                     'R type RT, R encoding RE, R local_cache RLC, R source_url RSU, R path RP,'
                     'R import_revision_content RIRC, R cw_source S, S name "system"')
                 for vcsrepo in reposrset.entities():
+                    # watch for repository being shut-down, our thread may:
+                    # * not receive the KeyboardInterrupt or shutdown signal
+                    # * loop a while without accessing the session (actually
+                    #   until some repository is actually not up-to-date, while
+                    #   this access to the session would abort the task)
+                    if repo.shutting_down:
+                        break
                     try:
                         repohdlr = bridge.repository_handler(vcsrepo)
                     except bridge.VCSException, ex:
@@ -136,6 +143,8 @@ class VCSFileStartHook(hook.Hook):
                            and vcsrepo.local_cache is not None:
                         try:
                             repohdlr.pull_or_clone_cache(vcsrepo.source_url)
+                        except bridge.VCSException, ex:
+                            repohdlr.error(str(ex))
                         except Exception:
                             repohdlr.exception(
                                 'error while updating local cache of repository %s',
