@@ -9,6 +9,7 @@ from __future__ import with_statement
 
 __docformat__ = "restructuredtext en"
 
+import urllib2
 from os import umask, makedirs
 from os.path import split, exists, join, dirname
 from datetime import datetime
@@ -82,12 +83,18 @@ class HGRepository(repo.VCSRepository):
             if not exists(pdir):
                 makedirs(pdir)
             self.info('cloning %s into %s', url, self.path)
-            hgcmd.clone(vcsfile_ui(self), str(url),
-                        dest=self.path, stream='compressed', noupdate=True)
+            try:
+                hgcmd.clone(vcsfile_ui(self), str(url),
+                            dest=self.path, stream='compressed', noupdate=True)
+            except (util.Abort, urllib2.URLError), ex:
+                raise bridge.VCSException(str(ex))
         else:
             self.info('pulling from %s into %s', remove_authinfo(url), self.path)
             vui = vcsfile_ui(self)
-            hgcmd.pull(vui, hg.repository(vui, self.path), source=str(url))
+            try:
+                hgcmd.pull(vui, hg.repository(vui, self.path), source=str(url))
+            except (util.Abort, urllib2.URLError), ex:
+                raise bridge.VCSException(str(ex))
 
     def import_content(self, repoentity, commitevery=10):
         """import content from the mercurial repository"""
