@@ -22,7 +22,7 @@ def _read_file_content(root, path):
     content = Binary()
     try:
         stream = fs.file_contents(root, path)
-    except:
+    except Exception:
         return None
     while 1:
         data = core.svn_stream_read(stream, core.SVN_STREAM_CHUNK_SIZE)
@@ -77,7 +77,7 @@ class SVNRepository(repo.VCSRepository):
                                  import_revision_content = repoentity.import_revision_content)
             try:
                 editor.import_revision()
-            except:
+            except Exception:
                 self.critical('error while importing revision %s of %s',
                               rev, repoentity.path, exc_info=True)
                 raise
